@@ -1,7 +1,7 @@
 package Db::Documentum;
 
 # Documentum.pm
-# (c) 2002 MS Roth
+# (c) 2004 M. Scott Roth
 
 use strict;
 use Carp;
@@ -16,7 +16,8 @@ require AutoLoader;
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 @EXPORT = qw();
-$VERSION = '1.53';
+
+$VERSION = '1.6';
 
 @EXPORT_OK = qw(
 	dmAPIInit
@@ -62,8 +63,8 @@ die "\nERROR: Db::Documentum could not properly initialize the Documentum API in
       unless dmAPIInit();
 
 ## Automatic API de-initialization code
-END
-{  warn "\nWARNING: Db::Documentum could not properly de-initialize the Documentum API interface.\n\n"
+END {
+      warn "\nWARNING: Db::Documentum could not properly de-initialize the Documentum API interface.\n\n"
       unless dmAPIDeInit();
 }
 
@@ -71,10 +72,13 @@ END
 ## invoke with: perl -MDb::Documentum -e Db::Documentum::version
 
 sub version {
-	print "\n\nDb::Documentum version: $VERSION\n";
+	print "\n\nPerl version: $]\n";
+	print "Db::Documentum version: $VERSION\n";
 	print "DMCL version: " . dmAPIGet("get,apisession,apiconfig,r_dmcl_version") . "\n\n";
 }
 
+## -----------------
+##      <SDG><
 ## -----------------
 
 1;
@@ -83,32 +87,31 @@ __END__
 
 =head1 NAME
 
-Db::Documentum - Perl extension for Documentum Client Libraries.
+Db::Documentum - Documentum API interface for Perl.
 
 =head1 SYNOPSIS
 
-	use Db::Documentum;
 	use Db::Documentum qw(:all);
 
-	string = dmAPIGet(<method>);
+	scalar = dmAPIGet(<method>);
 	$sessionID = dmAPIGet("connect,docbase,username,password");
 
 	scalar = dmAPIExec(<method>);
-	$obj_id = dmAPIExec("create,c,dm_document");
+	$rv = dmAPIExec("next,c,$collection_id");
 
 	scalar = dmAPISet(<method>,<value>);
 	$api_stat = dmAPISet("set,c,last,object_name","My Document");
 
+    See scripts in /etc for more examples.
 
 =head1 DESCRIPTION
 
 The B<Db::Documentum> module provides a Perl interface to
 the client API libraries for the Documentum Enterprise Document
-Management System (EDMS98 and 4i). You must have already
+Management System (EDMS98/4i/5). You must have already
 obtained the necessary libraries and purchased the necessary
 licenses from Documentum before you can build this module. For
-more information on Documentum EDMS, see
-I<http://www.documentum.com/>
+more information on Documentum, see I<http://www.documentum.com/>
 
 This module provides an interface to the three listed API
 functions: B<dmAPIGet>, B<dmAPIExec>, and B<dmAPISet>. For most purposes,
@@ -128,7 +131,7 @@ called with the fully-qualified package path:
 	Db::Documentum::dmAPIGet
 
 To use the module functions without having to supply the module name,
-use the second form of the "use" statement shown above:
+use the second form of the "use" statement shown here:
 
 	use Db::Documentum qw (:all);
 
