@@ -1,6 +1,6 @@
 #! /usr/local/bin/perl -w
 # idql.pl
-# (c) 2000 MS Roth
+# (c) 2000-2004 MS Roth
 
 # ver 1.0 - July 2000
 #           * Initially released with 'An Introduction to Db::Documentum'
@@ -8,14 +8,13 @@
 #           * Updated slightly for and released with Db::documentum 1.4
 # ver 1.2 - November 2000
 #           * Minor updates to fix results formatting problem
-#           + TODO: use Term::ANSIColor?
-#           + TODO: return results as hash?
-#           + TODO: make results columns only as wide as largest result returned
+# ver 1.3 - September 2004
+#           * Made results column width's only as wide as necessary
 
 use Db::Documentum qw(:all);
 use Db::Documentum::Tools qw (:all);
 use Term::ReadKey;
-$VERSION = "1.2";
+$VERSION = "1.3";
 
 logon();
 
@@ -37,8 +36,9 @@ while (1) {
 }
 
 sub logon {
-    print "\n" x 10;
-    print "(c) 2000 MS Roth. Distributed as part of Db::Documentum\n";
+    ReadMode 'normal';
+    print "\n" x 5;
+    print "(c) 2004 MS Roth. Distributed as part of Db::Documentum\n";
     print "Db::Documentum Interactive Document Query Language Editor $VERSION\n";
     print "----------------------------------------------------------------\n";
     print "Enter Docbase Name: ";
@@ -65,55 +65,84 @@ sub do_DQL {
 
     print "\n\n";
 
-    # do sql and print results
+    # do query
     $api_stat = dmAPIExec("execquery,$SESSION,F,$dql");
 
     if ($api_stat) {
         $col_id = dmAPIGet("getlastcoll,$SESSION");
 
-        # get _count
+        # get attr count so we know how many columns in result set
         $attr_count = dmAPIGet("get,$SESSION,$col_id,_count");
 
         if ($attr_count > 0) {
-            # get _names and _lengths
-            @attr_names = ();
-            @attr_lengths = ();
+            # get names and lengths of attrs
+            my @attr_names = ();
+            my @attr_lengths = ();
+            my @rows = ();
 
             for ($i=0; $i<$attr_count; $i++) {
-                push(@attr_names,dmAPIGet("get,$SESSION,$col_id,_names[$i]"));
-                my $attrlen = dmAPIGet("get,$SESSION,$col_id,_lengths[$i]");
-                if ($attrlen < 16) { $attrlen = 16; }
-                push(@attr_lengths,$attrlen);
+               push(@attr_names,dmAPIGet("get,$SESSION,$col_id,_names[$i]"));
+               push(@attr_lengths,length($attr_names[$i]));
             }
 
+            # get rows
+            $row_counter = 0;
+            while (dmAPIExec("next,$SESSION,$col_id")) {
+                my $attr_counter = 0;
+                my $attr_string = "";
+
+                foreach my $attrname (@attr_names) {
+                    my $value = dmAPIGet("get,$SESSION,$col_id,$attrname");
+
+                    # build delimited string for each row
+                    $attr_string .= $value . "::";
+
+                    # update column width is value exceeds current width
+                    if (length($value) > $attr_lengths[$attr_counter]) {
+                        $attr_lengths[$attr_counter] = length($value);
+                    }
+                    $ attr_counter++;
+                }
+
+                # save delimited row
+                push(@rows,$attr_string);
+                $row_counter++;
+            }
+            dmAPIExec("close,$SESSION,$col_id");
+
             # print attr names
             for ($i=0; $i<$attr_count; $i++) {
                 print $attr_names[$i];
-                print " " x ($attr_lengths[$i] - length($attr_names[$i]) . " ");
+                print " " x ($attr_lengths[$i] - length($attr_names[$i]));
+                print " ";
             }
             print "\n";
 
             # print underbars for attr names
             for ($i=0; $i<$attr_count; $i++) {
-                print "-" x $attr_lengths[$i] . " ";
+                print "-" x $attr_lengths[$i];
+                print " ";
             }
             print "\n";
 
-            # print attr values
-            $row_counter = 0;
-            while (dmAPIExec("next,$SESSION,$col_id")) {
-                my $attr_counter = 0;
-                foreach my $name (@attr_names) {
-                    my $value = dmAPIGet("get,$SESSION,$col_id,$name");
-                    print $value;
-                    print " " x ($attr_lengths[$attr_counter] - length($value)) . " ";
-                    $attr_counter++;
+            # print results
+            foreach my $row (@rows) {
+
+                # split string on delimiter
+                my @cols = split('::',$row);
+                my $col_count = 0;
+
+                foreach (@cols) {
+                    print $_ ;
+                    print " " x ($attr_lengths[$col_count] - length($_));
+                    print " ";
+                    $col_count++;
                 }
                 print "\n";
-                $row_counter++;
             }
+
             print "\n[$row_counter row(s) affected]\n\n";
-            dmAPIExec("close,$SESSION,$col_id");
+
         }
     }
     print dm_LastError($SESSION,3,'all');
@@ -126,4 +155,9 @@ sub do_Quit {
     exit;
 }
 
-# __EOF__   
\ No newline at end of file
+
+## -----------------
+##      <SDG><
+## -----------------
+
+# __EOF__
\ No newline at end of file
